about summary refs log tree commit diff
path: root/src
diff options
context:
space:
mode:
authorMatthias Krüger <matthias.krueger@famsik.de>2022-01-18 04:42:03 +0100
committerGitHub <noreply@github.com>2022-01-18 04:42:03 +0100
commitae8f39e4d467c4f9d21539070b7f82914f48eaa3 (patch)
treea187a528cd425f880f0bc4222cd9202f57b76c1d /src
parentdeee6f770f755e4f7c1c0001b353a72ca75b1902 (diff)
parenta7092f91a6015dd32aab978b05c4b346d790aaaa (diff)
downloadrust-ae8f39e4d467c4f9d21539070b7f82914f48eaa3.tar.gz
rust-ae8f39e4d467c4f9d21539070b7f82914f48eaa3.zip
Rollup merge of #92866 - maxwase:does_exist_typo, r=Mark-Simulacrum
"Does exists" typos fix

Fixed some typos
Diffstat (limited to 'src')
-rw-r--r--src/bootstrap/bootstrap.py2
-rw-r--r--src/bootstrap/bootstrap_test.py4
2 files changed, 3 insertions, 3 deletions
diff --git a/src/bootstrap/bootstrap.py b/src/bootstrap/bootstrap.py
index 7c36bb264c4..6d7ab15326c 100644
--- a/src/bootstrap/bootstrap.py
+++ b/src/bootstrap/bootstrap.py
@@ -863,7 +863,7 @@ class RustBuild(object):
         >>> rb.get_toml("key2")
         'value2'
 
-        If the key does not exists, the result is None:
+        If the key does not exist, the result is None:
 
         >>> rb.get_toml("key3") is None
         True
diff --git a/src/bootstrap/bootstrap_test.py b/src/bootstrap/bootstrap_test.py
index 7bffc1c1520..06ca3ce21b3 100644
--- a/src/bootstrap/bootstrap_test.py
+++ b/src/bootstrap/bootstrap_test.py
@@ -55,8 +55,8 @@ class ProgramOutOfDate(unittest.TestCase):
     def tearDown(self):
         rmtree(self.container)
 
-    def test_stamp_path_does_not_exists(self):
-        """Return True when the stamp file does not exists"""
+    def test_stamp_path_does_not_exist(self):
+        """Return True when the stamp file does not exist"""
         if os.path.exists(self.rustc_stamp_path):
             os.unlink(self.rustc_stamp_path)
         self.assertTrue(self.build.program_out_of_date(self.rustc_stamp_path, self.key))